==> nextcloud-25.0.11.tgz: nextcloud/apps/systemtags/l10n/et_EE.js <==
OC.L10N.register(
    "systemtags",
    {
    "Update" : "Uuenda",
    "Create" : "Loo",
    "Select tag …" : "Vali silt ...",
    "Added system tag {systemtag}" : "Lisas süsteemi sildi {systemtag}",
    "Added system tag %1$s" : "Lisas süsteemi sildi %1$s",
    "%1$s added system tag %2$s" : "%1$s lisas süsteemi sildi %2$s",
    "{actor} added system tag {systemtag}" : "{actor} lisas süsteemi sildi {systemtag}",
    "Removed system tag {systemtag}" : "Eemaldas süsteemi sildi {systemtag}",
    "Removed system tag %1$s" : "Eemaldas süsteemi sildi %1$s",
    "%1$s removed system tag %2$s" : "%1$s eemaldas süsteemi sildi %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eemaldas süsteemi sildi {systemtag}",
    "You created system tag %1$s" : "Sa lõid süsteemi sildi %1$s",
    "You created system tag {systemtag}" : "Sa lõid süsteemi sildi {systemtag}",
    "%1$s created system tag %2$s" : "%1$s lõi süsteemi sildi %2$s",
    "{actor} created system tag {systemtag}" : "{actor} lõi süsteemi sildi {systemtag}",
    "You deleted system tag %1$s" : "Sa kustutasid süsteemi sildi %1$s",
    "You deleted system tag {systemtag}" : "Sa kustutasid süsteemi sildi {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s kustutas süsteemi sildi %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} kustutas süsteemi sildi {systemtag}",
    "You updated system tag %2$s to %1$s" : "Sa uuendasid süsteemi sildi %2$s => %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Sa uuendasid süsteemi sildi {oldsystemtag} => {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uuendas süsteemi sildi %3$s => %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uuendas süsteemi sildi {oldsystemtag} => {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Sa lisasid süsteemi sildi %2$s => %1$s",
    "You added system tag {systemtag} to {file}" : "Sa lisasid süsteemi sildi {systemtag} failile {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s lisas süsteemi sildi %3$s => %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} lisas süsteemi sildi {systemtag} failile {file}",
    "You removed system tag %2$s from %1$s" : "Sa eemaldasid süsteemi sildi %2$s - %1$s",
    "You removed system tag {systemtag} from {file}" : "Sa eemaldasid süsteemi sildi {systemtag} {file} faililt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eemaldas süsteemi sildi %3$s - %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eemaldas süsteemi sildi {systemtag} {file} faililt",
    "%s (restricted)" : "%s (piiratud)",
    "%s (invisible)" : "%s (nähtamatu)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Süsteemi sildid</strong> sellele failile on muudetud",
    "Tags" : "Sildid",
    "Collaborative tags" : "Koostöö sildid",
    "This file has the tag {tag}" : "Sellel failil on silt {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Sellel failil on sildid {firstTags} and {lastTag}",
    "Tagged files" : "Sildistatud failid",
    "Select tags to filter by" : "Vali sildid, mille järgi filtreerida",
    "No tags found" : "Silte ei leitud",
    "Please select tags to filter by" : "Palun vali sildid, mille järgi filtreerida",
    "No files found for the selected tags" : "Valitud siltidega ei leitud ühtegi faili",
    "Name" : "Nimi",
    "Public" : "Avalik",
    "Restricted" : "Piiratud",
    "Invisible" : "Nähtamatu",
    "Delete" : "Kustuta",
    "Reset" : "Lähtesta",
    "No files in here" : "Siin ei ole faile",
    "No entries found in this folder" : "Selles kaustast ei leitud kirjeid",
    "Size" : "Suurus",
    "Modified" : "Muudetud"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.12.tgz: nextcloud/apps/systemtags/l10n/et_EE.js <==
OC.L10N.register(
    "systemtags",
    {
    "Update" : "Uuenda",
    "Create" : "Loo",
    "Select tag …" : "Vali silt ...",
    "Added system tag {systemtag}" : "Lisas süsteemi sildi {systemtag}",
    "Added system tag %1$s" : "Lisas süsteemi sildi %1$s",
    "%1$s added system tag %2$s" : "%1$s lisas süsteemi sildi %2$s",
    "{actor} added system tag {systemtag}" : "{actor} lisas süsteemi sildi {systemtag}",
    "Removed system tag {systemtag}" : "Eemaldas süsteemi sildi {systemtag}",
    "Removed system tag %1$s" : "Eemaldas süsteemi sildi %1$s",
    "%1$s removed system tag %2$s" : "%1$s eemaldas süsteemi sildi %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eemaldas süsteemi sildi {systemtag}",
    "You created system tag %1$s" : "Sa lõid süsteemi sildi %1$s",
    "You created system tag {systemtag}" : "Sa lõid süsteemi sildi {systemtag}",
    "%1$s created system tag %2$s" : "%1$s lõi süsteemi sildi %2$s",
    "{actor} created system tag {systemtag}" : "{actor} lõi süsteemi sildi {systemtag}",
    "You deleted system tag %1$s" : "Sa kustutasid süsteemi sildi %1$s",
    "You deleted system tag {systemtag}" : "Sa kustutasid süsteemi sildi {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s kustutas süsteemi sildi %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} kustutas süsteemi sildi {systemtag}",
    "You updated system tag %2$s to %1$s" : "Sa uuendasid süsteemi sildi %2$s => %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Sa uuendasid süsteemi sildi {oldsystemtag} => {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uuendas süsteemi sildi %3$s => %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uuendas süsteemi sildi {oldsystemtag} => {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Sa lisasid süsteemi sildi %2$s => %1$s",
    "You added system tag {systemtag} to {file}" : "Sa lisasid süsteemi sildi {systemtag} failile {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s lisas süsteemi sildi %3$s => %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} lisas süsteemi sildi {systemtag} failile {file}",
    "You removed system tag %2$s from %1$s" : "Sa eemaldasid süsteemi sildi %2$s - %1$s",
    "You removed system tag {systemtag} from {file}" : "Sa eemaldasid süsteemi sildi {systemtag} {file} faililt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eemaldas süsteemi sildi %3$s - %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eemaldas süsteemi sildi {systemtag} {file} faililt",
    "%s (restricted)" : "%s (piiratud)",
    "%s (invisible)" : "%s (nähtamatu)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Süsteemi sildid</strong> sellele failile on muudetud",
    "Tags" : "Sildid",
    "Collaborative tags" : "Koostöö sildid",
    "This file has the tag {tag}" : "Sellel failil on silt {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Sellel failil on sildid {firstTags} and {lastTag}",
    "No tags found" : "Silte ei leitud",
    "Name" : "Nimi",
    "Public" : "Avalik",
    "Restricted" : "Piiratud",
    "Invisible" : "Nähtamatu",
    "Delete" : "Kustuta",
    "Reset" : "Lähtesta",
    "No files in here" : "Siin ei ole faile",
    "No entries found in this folder" : "Selles kaustast ei leitud kirjeid",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "Tagged files" : "Sildistatud failid",
    "Select tags to filter by" : "Vali sildid, mille järgi filtreerida",
    "Please select tags to filter by" : "Palun vali sildid, mille järgi filtreerida",
    "No files found for the selected tags" : "Valitud siltidega ei leitud ühtegi faili"
},
"nplurals=2; plural=(n != 1);");
